@@ -1,11 +1,11 @@
 /* VRectangle.m
  * 2-D Rectangle object
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-09-17
- * modified: 2005-10-18 (rounded corners for rectangles within Paths added)
+ * modified: 2006-02-08
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -132,7 +132,7 @@
 #define CREATEEVENTMASK NSLeftMouseDraggedMask|NSLeftMouseDownMask|NSLeftMouseUpMask|NSPeriodicMask
 - (BOOL)create:(NSEvent *)event in:(DocView*)view
 {   NSRect	viewBounds, gridBounds, drawBounds;
-    NSPoint	start, last, gridPoint, drawPoint, rSize, p, lastPoint, hitPoint;
+    NSPoint	start, last, gridPoint, drawPoint, rSize, p, lastPoint = NSZeroPoint, hitPoint;
     id		window = [view window];
     VRectangle 	*drawRectangleGraphic;
     BOOL	ok = YES, dragging = NO, hitEdge = NO, inTimerLoop = NO;
@@ -608,8 +608,7 @@
 {
     if ( !radius && !rotAngle && filled < 2 )
     {
-        [NSBezierPath setDefaultLineWidth:width];
-        [NSBezierPath setDefaultLineCapStyle:NSRoundLineCapStyle];
+        [NSBezierPath setDefaultLineCapStyle: NSRoundLineCapStyle];
         [NSBezierPath setDefaultLineJoinStyle:NSRoundLineJoinStyle];
 
         if ( filled )
@@ -636,6 +635,7 @@
         }
         if ( width > 0.0 || !filled )
         {   NSColor	*oldColor=nil;
+            float	defaultWidth = [NSBezierPath defaultLineWidth];
 
             if (!VHFIsDrawingToScreen() && [principal separationColor])
             {   NSColor	*sepColor = [self separationColor:color]; // get individual separation color
@@ -644,7 +644,9 @@
                 [self setColor:sepColor];
             }
             [super drawWithPrincipal:principal];	// set color
+            [NSBezierPath setDefaultLineWidth:(width > 0.0) ? width : defaultWidth];
             [NSBezierPath strokeRect:NSMakeRect(origin.x, origin.y, Max( 0.01, size.x), Max( 0.01, size.y))];
+            [NSBezierPath setDefaultLineWidth:defaultWidth];
 
             if (!VHFIsDrawingToScreen() && [principal separationColor])
             {   [self setColor:oldColor];
@@ -1015,9 +1017,8 @@
         [self getPoint:i :&p];
         knobRect.origin.x = p.x - controlsize/2.0;
         knobRect.origin.y = p.y - controlsize/2.0;
-        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (selectedKnob != i && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p;
-            selectedKnob = i;
             return YES;
         }
     }
@@ -1471,9 +1472,9 @@
      */
     first = YES;
     removing = NO;
-    for ( i=startI, listCnt = [[ng list] count]; first || i != startI; i++ )
+    for ( i=startI, listCnt = [[ng list] count]; startI != -1 && (first || i != startI); i++ )
     {	id	gThis;
-        NSPoint	gPrevE;
+        NSPoint	gPrevE = NSZeroPoint;
         BOOL	currentlyRemoved = NO;
 
         i = (i >= listCnt) ? 0 : i;
@@ -1716,7 +1717,7 @@
     for (i=0; i< sPairsCnt; i++)
     {   int	sptCnt = sPairsCnts[i], eptCnt = ePairsCnts[i], sIx = 1;
         int	sIs[2], eIs[2], sI0 = -1, eI0 = -1, endI = -1;
-        NSPoint	sPts[2], ePts[2];
+        NSPoint	sPts[2], ePts[2] = {NSZeroPoint, NSZeroPoint};
 
         /* count with i and sePairsCnts to the current startIs/startPts index */
         sI0 = 0;
@@ -1751,9 +1752,9 @@
                 for (k=0; k < sPairsCnt; k++)
                 {
                     if ((startIs[si] < listCnt &&
-                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                        (endIs[si] < listCnt &&
-                         [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                        [gj identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                         // || (endIs[si] < listCnt &&
+                         // [gj identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                     {
                         [splitListUg removeObjectAtIndex:j];
                         /* korrect all uStartIs behind j */
@@ -1879,9 +1880,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                                        (endIs[si] < listCnt &&
-                                         [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                                         [gkn identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                                    // || (endIs[si] < listCnt &&
+                                    // [gkn identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                                     {
                                         gknIsDouble = YES;
                                         break;
@@ -1965,9 +1966,9 @@
                                 for (l=0; l < sPairsCnt; l++)
                                 {
                                     if ((startIs[si] < listCnt &&
-                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]) ||
-                                        (endIs[si] < listCnt &&
-                                         [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]]))
+                                         [gkp identicalWith:[[ng list] objectAtIndex:startIs[si]]]))
+                                    // || (endIs[si] < listCnt &&
+                                    // [gkp identicalWith:[[ng list] objectAtIndex:endIs[si]]])
                                     {
                                         gkpIsDouble = YES;
                                         break;
