@@ -1,11 +1,11 @@
 /* VText.m
  * 2-D Text object
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-02-15
- * modified: 2005-09-01 (replaceSubstring:withString:)
+ * modified: 2006-09-20 (scroll editing text to visible)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -37,8 +37,8 @@
 #include "../FlippedView.h"
 #include "../graphicsUndo.subproj/undo.h"
 
-static NSTextView	*drawText = nil;	/* shared Text object used for drawing */
-//static NSString		*fontListNoFill;	/* list of fonts which shouldn't be filled */
+static NSTextView	*drawText = nil;	// shared Text object used for drawing
+//static NSString	*fontListNoFill;	// list of fonts which shouldn't be filled
 //static BOOL 		displayModeFilled = YES;
 
 //#define FONTLIST_NAME	@"FontListNoFill"
@@ -252,7 +252,8 @@ static void initClassVars()
     [drawText setHorizontallyResizable:YES];
     [drawText setVerticallyResizable:YES];
     [ts beginEditing];
-    [ts setAttributedString:attributedString];
+    if (attributedString)
+        [ts setAttributedString:attributedString];
     [ts endEditing];
     [drawText setAlignment:NSLeftTextAlignment];
     [drawText setString:s];
@@ -277,7 +278,7 @@ static void initClassVars()
     }
     if (color)
         [drawText setTextColor:color];
-    [drawText sizeToFit];	/* collapses to zero for text larger bounds ??? */
+    [drawText sizeToFit];	// collapses to zero for text larger bounds ???
 
     [self setAttributedString:[ts attributedSubstringFromRange:NSMakeRange(0, [ts length])]];
     [[drawText textContainer] setWidthTracksTextView:YES];
@@ -435,6 +436,8 @@ static void initClassVars()
 }
 
 /*
+ * modified: 2006-09-20 (scroll text to visible)
+ *
  * Here we are going to use the shared field editor for the window to
  * edit the text in the VText.  First, we must end any other editing
  * that is going on with the field editor in this window using endEditingFor:.
@@ -608,6 +611,7 @@ static void initClassVars()
 	[fe setSelectedRange:(NSRange){0,0}];
 
     [fe toggleRuler:self];
+    [view scrollRectToVisible:frame];	// if ruler covers text -> scroll text to visible
 
     return YES;
 }
@@ -1596,6 +1600,7 @@ static void initClassVars()
 #ifdef __APPLE__
     {   NSBezierPath	*bezierPath = [NSBezierPath bezierPath];
         NSFont		*fnt;
+        float		yOffset = Max(0.0, (bounds.size.height-rect.size.height-1.0)/2.0);
 
         cnt = [lm numberOfGlyphs];
         if (cnt > 1)
@@ -1608,7 +1613,7 @@ static void initClassVars()
             p = [lm locationForGlyphAtIndex:i];
             [bezierPath removeAllPoints];
             [bezierPath moveToPoint:NSMakePoint(bRect.origin.x+rect.origin.x+p.x,
-                                                bRect.origin.y+bRect.size.height-rect.origin.y-p.y)];
+                                                bRect.origin.y+bRect.size.height-rect.origin.y-p.y-yOffset)];
             fnt = [[drawText textStorage] attribute:NSFontAttributeName atIndex:i effectiveRange:NULL];
             [bezierPath appendBezierPathWithGlyph:[lm glyphAtIndex:i] inFont:fnt];
             pathG = [VPath pathWithBezierPath:bezierPath];
